Documentation
¶
Overview ¶
Package testr provides support for using logr in tests.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Options ¶
type Options struct {
// LogTimestamp tells the logger to add a "ts" key to log
// lines. This has some overhead, so some users might not want
// it.
LogTimestamp bool
// Verbosity tells the logger which V logs to be write.
// Higher values enable more logs.
Verbosity int
}
Options carries parameters which influence the way logs are generated.
Click to show internal directories.
Click to hide internal directories.